common name starts with
Usage
common_contains(
name,
provider = getOption("taxadb_default_provider", "itis"),
version = latest_version(),
db = td_connect(),
ignore_case = TRUE
)Arguments
- name
vector of names (scientific or common, see
by) to be matched against.- provider
from which provider should the hierarchy be returned? Default is 'itis', which can also be configured using
options(default_taxadb_provider=..."). See[td_create]for a list of recognized providers.- version
Which version of the taxadb provider database should we use? defaults to latest. See tl_import for details.
- db
a connection to the taxadb database. See details.
- ignore_case
should we ignore case (capitalization) in matching names? Can be significantly slower to run.
Examples
# \donttest{
common_contains("monkey")
#> duckdb keeps downloaded extensions and secrets in a temporary directory:
#> ℹ /tmp/Rtmpyk12yP/duckdb
#> This is removed when the R session ends.
#> • Extensions are re-downloaded each session.
#> • Secrets are lost.
#> ℹ Run duckdb(shared_home = TRUE) (or create ~/.duckdb) to keep them (suitable for most users).
#> ℹ Run duckdb(shared_home = FALSE) to accept the temporary directory (and silence this message).
#> ℹ See ?duckdb_storage for details and alternatives.
#> Error in tbl(dbplyr::src_dbi(src, auto_disconnect = FALSE), from = from, ...): `...` must be empty.
#> ✖ Problematic argument:
#> • check_from = FALSE
# }