Superseded by td_download().
Usage
td_create(
provider = getOption("taxadb_default_provider", "itis"),
schema = c("dwc", "common"),
version = latest_version(),
overwrite = FALSE,
lines = NULL,
dbdir = NULL,
db = td_connect()
)Arguments
- provider
a character vector of provider(s) to download. See
available_providers()for the providers published in a given version.- schema
One of "dwc" (for Darwin Core data) or "common" (for the Common names table.)
- version
Which version of the taxadb provider database should we use? defaults to latest. See
available_versions()for details.- overwrite
passed to
td_download()- lines
deprecated, ignored.
- dbdir
deprecated, ignored.
- db
a connection to the taxadb database. See details.
Details
taxadb no longer needs to import data before querying it:
tables are read directly from Parquet, streamed from remote storage or
from a local copy. td_create() is retained as an alias for
td_download(), which installs a local copy.