List the taxonomic snapshots available from the taxadb repository
Source:R/taxadb_source.R
list_snapshots.RdList the taxonomic snapshots available from the taxadb repository
Usage
list_snapshots(db = td_connect())Arguments
- db
a connection from
td_connect()