View source: R/taxadb_source.R
| list_snapshots | R Documentation |
List the taxonomic snapshots available from the taxadb repository
list_snapshots(db = td_connect())
db |
a connection from |
Requires network access. Results are cached for the session.
a data.frame with one row per published Parquet file, giving its
version, schema, provider and uri.
## Not run:
list_snapshots()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.