Skip to contents

Return a reference to a given table in the taxadb database

Usage

taxa_tbl(
  provider = getOption("taxadb_default_provider", "itis"),
  schema = c("dwc", "common"),
  version = latest_version(),
  db = td_connect()
)

Arguments

provider

from which provider should the hierarchy be returned? Default is 'itis', which can also be configured using options(default_taxadb_provider=..."). See [td_create] for a list of recognized providers.

schema

One of "dwc" (for Darwin Core data) or "common" (for the Common names table.)

version

Which version of the taxadb provider database should we use? defaults to latest. See tl_import for details.

db

a connection to the taxadb database. See details.

Examples

# \donttest{

  ## default schema is the dwc table
  taxa_tbl()
#> Error in tbl(dbplyr::src_dbi(src, auto_disconnect = FALSE), from = from,     ...): `...` must be empty.
#>  Problematic argument:
#>  check_from = FALSE

  ## common names table
  taxa_tbl(schema = "common")
#> Error in tbl(dbplyr::src_dbi(src, auto_disconnect = FALSE), from = from,     ...): `...` must be empty.
#>  Problematic argument:
#>  check_from = FALSE



# }