taxa_tbl: Return a reference to a given table in the taxadb database

View source: R/taxa_tbl.R

taxa_tblR Documentation

Return a reference to a given table in the taxadb database

Description

Return a reference to a given table in the taxadb database

Usage

taxa_tbl(
  provider = getOption("taxadb_default_provider", "itis"),
  schema = c("dwc", "common"),
  version = latest_version(),
  db = td_connect()
)

Arguments

provider

from which provider should the hierarchy be returned? Default is 'itis', which can also be configured using ⁠options(default_taxadb_provider=...")⁠. See ⁠[td_create]⁠ for a list of recognized providers.

schema

One of "dwc" (for Darwin Core data) or "common" (for the Common names table.)

version

Which version of the taxadb provider database should we use? defaults to latest. See available_versions() for details.

db

a connection to the taxadb database. See details.

Details

The returned table is a duckdb view over Parquet, so it can be manipulated with any dplyr verb and is only ever read to the extent your query requires. Unless a local copy has been installed with td_download(), the data is streamed from remote storage on demand.

Value

a lazy dplyr table backed by the requested Parquet snapshot.

Examples


  

  ## default schema is the Darwin Core table
  taxa_tbl()

  ## common names table
  taxa_tbl(schema = "common")

  


taxadb documentation built on Aug. 31, 2026, 5:07 p.m.