View source: R/taxadb_source.R
| taxadb_uri | R Documentation |
Locate the Parquet files backing a taxadb table
taxadb_uri(
provider = getOption("taxadb_default_provider", "itis"),
schema = c("dwc", "common"),
version = latest_version(),
local = NULL
)
provider |
from which provider should the hierarchy be returned?
Default is 'itis', which can also be configured using |
schema |
One of "dwc" (for Darwin Core data) or "common" (for the Common names table.) |
version |
Which version of the taxadb provider database should we use?
defaults to latest. See |
local |
should we return the path to a local snapshot? By default
a local copy is used when one is present (see |
a glob pattern (or file path) that duckdb can read
taxadb_uri("itis_test")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.